from setuptools import setup

setup(name='gistributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['gistributions'],
      author='Godwin',
      author_email='justg.techs@gmail.com',
      zip_safe=False)
